.. _large_deformation-hyperelastic_ul_by_fun:

large_deformation/hyperelastic_ul_by_fun.py
===========================================

**Description**


Compressible Neo-Hookean hyperelastic material model. The tangent modulus
and the stress tensor are calculated by a user defined function.


.. image:: /../doc/images/gallery/large_deformation-hyperelastic_ul_by_fun.png


:download:`source code </../sfepy/examples/large_deformation/hyperelastic_ul_by_fun.py>`

.. literalinclude:: /../sfepy/examples/large_deformation/hyperelastic_ul_by_fun.py

